==> skrooge-1.6.0.tar.bz2: skrooge-1.6.0/plugins/krunner/skrooge_add_operation/skgaddoperation.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGADDOPERATION_H
#define SKGADDOPERATION_H

#include <Plasma/AbstractRunner>

class SKGAddOperation : public Plasma::AbstractRunner
{
    Q_OBJECT

public:
    SKGAddOperation(QObject* parent, const QVariantList& args);
    void match(Plasma::RunnerContext& context);
    void run(const Plasma::RunnerContext& context, const Plasma::QueryMatch& match);
    void reloadConfiguration();

protected slots:
    void init();

private:
    QString m_triggerWord;
};

#endif

==> skrooge_1.8.0.orig.tar.bz2: skrooge-1.8.0/plugins/krunner/skrooge_add_operation/skgaddoperation.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGADDOPERATION_H
#define SKGADDOPERATION_H

#include <Plasma/AbstractRunner>

class SKGAddOperation : public Plasma::AbstractRunner
{
    Q_OBJECT

public:
    SKGAddOperation(QObject* iParent, const QVariantList& args);
    void match(Plasma::RunnerContext& context);
    void run(const Plasma::RunnerContext& context, const Plasma::QueryMatch& match);
    void reloadConfiguration();

protected slots:
    void init();

private:
    QString m_triggerWord;
};

#endif
